@@ -1,8 +1,10 @@
 """Subscribe and unsubscribe to pywebview events."""
 
-import webview
 from bottle import Bottle, request
 
+import webview
+
+
 def on_request(window, request):
     print('Request sent: ' + request.url)
     request.headers['pywebview'] = 'header'
@@ -14,15 +16,15 @@ def on_response(window, response):
 
 app = Bottle()
 
+
 @app.route('/')
 def display_headers():
     headers = dict(request.headers)
     return '<br>'.join(f'{key}: {value}' for key, value in headers.items())
 
+
 if __name__ == '__main__':
-    window = webview.create_window(
-        'Headers', app
-    )
+    window = webview.create_window('Headers', app)
 
     window.events.request_sent += on_request
     window.events.response_received += on_response
