@@ -7,7 +7,7 @@ def open_file_dialog(window):
     file_types = ('Image Files (*.bmp;*.jpg;*.gif)', 'All files (*.*)')
 
     result = window.create_file_dialog(
-        webview.OPEN_DIALOG, allow_multiple=True, file_types=file_types
+        webview.FileDialog.OPEN, allow_multiple=True, file_types=file_types
     )
     print(result)
 
