@@ -72,5 +72,7 @@ html = """
 
 if __name__ == '__main__':
     # Create a transparent webview window
-    webview.create_window('Transparent window', html=html, transparent=True, frameless=True)#, hidden=True)
+    webview.create_window(
+        'Transparent window', html=html, transparent=True, frameless=True
+    )  # , hidden=True)
     webview.start()
