@@ -1,5 +1,3 @@
-from time import sleep
-
 import webview
 
 from .util import assert_js, run_test
@@ -18,7 +16,6 @@ def test_start():
 
 def assert_func(window):
     window.events.loaded.wait()
-    print(window.evaluate_js('document.body.innerHTML'))
     html_result = window.evaluate_js('document.getElementById("heading").innerText')
     assert html_result == 'Hello there!'
 
