@@ -2,36 +2,42 @@ import json
 import logging
 import os
 import platform
+import signal
 import socket
 import sys
-import typing as t
 import webbrowser
 from copy import copy, deepcopy
 from functools import partial
 from threading import Event, Semaphore, Thread
 from uuid import uuid1
 
-from webview import (FOLDER_DIALOG, OPEN_DIALOG, SAVE_DIALOG, _settings, windows, settings)
+from webview import FileDialog, _state, settings, windows
 from webview.dom import _dnd_state
-from webview.js.css import disable_text_select
 from webview.menu import Menu, MenuAction, MenuSeparator
+from webview.models import Request
 from webview.screen import Screen
-from webview.util import DEFAULT_HTML, create_cookie, js_bridge_call, inject_pywebview, environ_append
+from webview.util import (
+    DEFAULT_HTML,
+    create_cookie,
+    environ_append,
+    inject_pywebview,
+    js_bridge_call,
+)
 from webview.window import FixPoint, Window
 
-logger = logging.getLogger('pywebview')
 
 from qtpy import QtCore
 
-logger.debug('Using Qt %s' % QtCore.__version__)
 
 from qtpy import PYQT6, PYSIDE6
-from qtpy.QtGui import QColor, QScreen
+from qtpy.QtCore import QByteArray, QJsonValue
+from qtpy.QtGui import QColor, QIcon, QScreen
 from qtpy.QtWidgets import QAction, QApplication, QFileDialog, QMainWindow, QMenuBar, QMessageBox
 
 try:
     from qtpy.QtNetwork import QSslCertificate, QSslConfiguration
     from qtpy.QtWebChannel import QWebChannel
+    from qtpy.QtWebEngineCore import QWebEngineUrlRequestInterceptor
     from qtpy.QtWebEngineWidgets import QWebEnginePage as QWebPage
     from qtpy.QtWebEngineWidgets import QWebEngineProfile, QWebEngineSettings
     from qtpy.QtWebEngineWidgets import QWebEngineView as QWebView
@@ -39,14 +45,16 @@ try:
     renderer = 'qtwebengine'
     is_webengine = True
 except ImportError:
-    from PyQt5 import QtWebKitWidgets
     from PyQt5.QtNetwork import QSslCertificate, QSslConfiguration
     from PyQt5.QtWebKitWidgets import QWebPage, QWebView
 
     is_webengine = False
     renderer = 'qtwebkit'
 
-if is_webengine and QtCore.QSysInfo.productType() in ['arch', 'manjaro', 'nixos','rhel']:
+logger = logging.getLogger('pywebview')
+logger.debug('Using Qt %s' % QtCore.__version__)
+
+if is_webengine and QtCore.QSysInfo.productType() in ['arch', 'manjaro', 'nixos', 'rhel', 'pop']:
     # I don't know why, but it's a common solution for #890 (White screen displayed)
     # such as:
     # - https://github.com/LCA-ActivityBrowser/activity-browser/pull/954/files
@@ -54,8 +62,8 @@ if is_webengine and QtCore.QSysInfo.productType() in ['arch', 'manjaro', 'nixos'
     # - https://www.google.com/search?q=arch+rstudio+no+sandbox
     # And sometimes it needs two "--no-sandbox" flags
 
-    environ_append("QTWEBENGINE_CHROMIUM_FLAGS", "--no-sandbox", "--no-sandbox")
-    logger.debug("Enable --no-sandbox flag for arch/manjaro/nixos")
+    environ_append('QTWEBENGINE_CHROMIUM_FLAGS', '--no-sandbox', '--no-sandbox')
+    logger.debug('Enable --no-sandbox flag for arch/manjaro/nixos')
 
 _main_window_created = Event()
 _main_window_created.clear()
@@ -63,20 +71,34 @@ _main_window_created.clear()
 # suppress invalid style override error message on some Linux distros
 os.environ['QT_STYLE_OVERRIDE'] = ''
 _qt6 = True if PYQT6 or PYSIDE6 else False
-_profile_storage_path = _settings['storage_path'] or os.path.join(os.path.expanduser('~'), '.pywebview')
+_profile_storage_path = _state['storage_path'] or os.path.join(
+    os.path.expanduser('~'), '.pywebview'
+)
+
+
+def _sigint_handler(signum, frame):
+    """
+    Handler for SIGINT signal (Ctrl+C).
+
+    Qt applications don't handle SIGINT by default because Python signal handlers
+    can only be called when the Python interpreter is running. Since the Qt event
+    loop runs in C++, signals are noted but handlers aren't called until Python
+    code executes. The timer in create_window() ensures the Python interpreter
+    runs periodically to process pending signals.
+
+    See: https://stackoverflow.com/a/4939113
+    """
+    global _app
+    if _app:
+        _app.quit()
 
 
 class BrowserView(QMainWindow):
     instances = {}
     inspector_port = None  # The localhost port at which the Remote debugger listens
 
-    # In case we don't have native menubar, we have to save the top level menus and add them
-    #     to each window's bar menu
-    global_menubar_top_menus = []
-    # If we don't save the rest of these, then QApplication can't access them
     global_menubar_other_objects = []
-    # The first QMenuBar created
-    global_menubar = None
+    global_menubar_top_menus = []
 
     create_window_trigger = QtCore.Signal(object)
     set_title_trigger = QtCore.Signal(str)
@@ -100,15 +122,20 @@ class BrowserView(QMainWindow):
     class JSBridge(QtCore.QObject):
         qtype = QtCore.QJsonValue if is_webengine else str
 
-        def __init__(self):
+        def __init__(self, parent):
             super(BrowserView.JSBridge, self).__init__()
+            self.parent = parent
+            self.window = parent.pywebview_window
 
         @QtCore.Slot(str, qtype, str, result=str)
         def call(self, func_name, param, value_id):
             func_name = BrowserView._convert_string(func_name)
             param = BrowserView._convert_string(param)
 
-            return js_bridge_call(self.window, func_name, json.loads(param), value_id)
+            if func_name == '_pywebviewAlert':
+                QMessageBox.information(self.parent, 'Message', str(param))
+            else:
+                return js_bridge_call(self.window, func_name, json.loads(param), value_id)
 
     class WebView(QWebView):
         def __init__(self, parent=None):
@@ -160,8 +187,7 @@ class BrowserView(QMainWindow):
             if e.mimeData().hasUrls and _dnd_state['num_listeners'] > 0:
                 files = [
                     (os.path.basename(value.toString()), value.toString().replace('file://', ''))
-                    for value
-                    in e.mimeData().urls()
+                    for value in e.mimeData().urls()
                     if value.toString().startswith('file://')
                 ]
                 _dnd_state['paths'] += files
@@ -176,9 +202,8 @@ class BrowserView(QMainWindow):
                 BrowserView.instances[uid].raise_()
                 BrowserView.instances[uid].activateWindow()
             except KeyError:
-                title = 'Web Inspector - {}'.format(self.parent().title)
-                url = 'http://localhost:{}'.format(BrowserView.inspector_port)
-                print(url)
+                title = f'Web Inspector - {self.parent().title}'
+                url = f'http://localhost:{BrowserView.inspector_port}'
                 window = Window('web_inspector', title, url, '', 700, 500)
                 window.localization = self.parent().localization
 
@@ -194,7 +219,7 @@ class BrowserView(QMainWindow):
         def mouseMoveEvent(self, event):
             parent = self.parent()
             if (
-                parent.frameless and parent.easy_drag and int(event.buttons()) == 1
+                parent.frameless and parent.easy_drag and event.buttons().value == 1
             ):  # left button is pressed
                 parent.move(event.globalPos() - self.drag_pos)
 
@@ -207,31 +232,59 @@ class BrowserView(QMainWindow):
 
             return False
 
+    class RequestInterceptor(QWebEngineUrlRequestInterceptor):
+        def __init__(self, window):
+            super().__init__()
+            self.window = window
+
+        def interceptRequest(self, info):
+            if len(self.window.events.request_sent) == 0:
+                return
+
+            url = info.requestUrl().toString()
+            method = info.requestMethod()
+
+            if 'httpHeaders' in dir(info):
+                headers = {
+                    k.data().decode('utf-8'): k.data().decode('utf-8')
+                    for k, v in info.httpHeaders().items()
+                }
+            else:
+                headers = {}
+
+            request = Request(url, method, headers)
+            self.window.events.request_sent.set(request)
+
+            if request.headers != headers:
+                for key, value in request.headers.items():
+                    info.setHttpHeader(
+                        QByteArray(key.encode('utf-8')), QByteArray(value.encode('utf-8'))
+                    )
+
     # New-window-requests handler for Qt 5.5+ only
     class NavigationHandler(QWebPage):
-        def __init__(self, page, parent):
-            self.parent = parent
-            super(BrowserView.NavigationHandler, self).__init__(page)
+        def __init__(self, page):
+            super().__init__(page.profile())
+            self._parent = page.parent
 
         def acceptNavigationRequest(self, url, type, is_main_frame):
             if settings['OPEN_EXTERNAL_LINKS_IN_BROWSER']:
                 webbrowser.open(url.toString(), 2, True)
                 return False
             else:
-                self.parent.load_url(url.toString())
+                self._parent.load_url(url.toString())
                 return True
 
     class WebPage(QWebPage):
         def __init__(self, parent=None, profile=None):
-            print(profile)
             if is_webengine and profile:
-                super(BrowserView.WebPage, self).__init__(profile, parent.view)
+                super(BrowserView.WebPage, self).__init__(profile, parent.webview)
             else:
-                super(BrowserView.WebPage, self).__init__(parent.view)
+                super(BrowserView.WebPage, self).__init__(parent.webview)
 
             if is_webengine:
                 self.featurePermissionRequested.connect(self.onFeaturePermissionRequested)
-                self.nav_handler = BrowserView.NavigationHandler(self, parent)
+                self.nav_handler = BrowserView.NavigationHandler(self)
             else:
                 self.nav_handler = None
 
@@ -242,14 +295,13 @@ class BrowserView(QMainWindow):
 
             def onFeaturePermissionRequested(self, url, feature):
                 if feature in (
-                    QWebPage.MediaAudioCapture,
-                    QWebPage.MediaVideoCapture,
-                    QWebPage.MediaAudioVideoCapture,
+                    QWebPage.Feature.MediaAudioCapture,
+                    QWebPage.Feature.MediaVideoCapture,
+                    QWebPage.Feature.MediaAudioVideoCapture,
                 ):
-                    self.setFeaturePermission(url, feature, QWebPage.PermissionGrantedByUser)
+                    self.setFeaturePermission(url, feature, 1)  # QWebPage.PermissionGrantedByUser
                 else:
-                    self.setFeaturePermission(url, feature, QWebPage.PermissionDeniedByUser)
-
+                    self.setFeaturePermission(url, feature, 2)  # QWebPage.PermissionDeniedByUser
         else:
 
             def acceptNavigationRequest(self, frame, request, type):
@@ -259,7 +311,7 @@ class BrowserView(QMainWindow):
                 return True
 
         def userAgentForUrl(self, url):
-            user_agent = _settings['user_agent']
+            user_agent = _state['user_agent']
             if user_agent:
                 return user_agent
             else:
@@ -273,19 +325,15 @@ class BrowserView(QMainWindow):
         BrowserView.instances[window.uid] = self
         self.uid = window.uid
         self.pywebview_window = window
+        self.pywebview_window.native = self
 
-        self.js_bridge = BrowserView.JSBridge()
-        self.js_bridge.window = window
+        self.js_bridge = BrowserView.JSBridge(self)
 
         self.is_fullscreen = False
-        self.text_select = window.text_select
 
         self._file_name_semaphore = Semaphore(0)
         self._current_url_semaphore = Semaphore(0)
 
-        self.loaded = window.events.loaded
-        self.shown = window.events.shown
-
         self.localization = window.localization
 
         if window.screen:
@@ -333,7 +381,6 @@ class BrowserView(QMainWindow):
             self.setAttribute(QtCore.Qt.WA_ShowWithoutActivating)
             flags = flags | QtCore.Qt.WindowDoesNotAcceptFocus
 
-
         self.setWindowFlags(flags)
         self.setAcceptDrops(True)
 
@@ -347,54 +394,65 @@ class BrowserView(QMainWindow):
             # Enable the transparency hint
             self.setAttribute(QtCore.Qt.WA_TranslucentBackground)
 
-        self.view = BrowserView.WebView(self)
+        self.webview = BrowserView.WebView(self)
 
         if is_webengine:
             environ_append(
-                'QTWEBENGINE_CHROMIUM_settings',
+                'QTWEBENGINE_CHROMIUM_FLAGS',
                 '--use-fake-ui-for-media-stream',
                 '--enable-features=AutoplayIgnoreWebAudio',
             )
 
-        user_agent = _settings['user_agent']
-        if user_agent and is_webengine:
-            self.view.page().profile().setHttpUserAgent(user_agent)
-
-        if _settings['debug'] and is_webengine:
+        if _state['debug'] and is_webengine:
             # Initialise Remote debugging (need to be done only once)
             if not BrowserView.inspector_port:
                 BrowserView.inspector_port = BrowserView._get_debug_port()
                 os.environ['QTWEBENGINE_REMOTE_DEBUGGING'] = BrowserView.inspector_port
         else:
-            self.view.setContextMenuPolicy(
+            self.webview.setContextMenuPolicy(
                 QtCore.Qt.NoContextMenu
             )  # disable right click context menu
 
+        self.cookies = {}
+
         if is_webengine:
-            if _settings['private_mode']:
+            self.request_interceptor = BrowserView.RequestInterceptor(self.pywebview_window)
+
+            if _state['private_mode']:
                 self.profile = QWebEngineProfile()
             else:
                 self.profile = QWebEngineProfile('pywebview')
                 self.profile.setPersistentStoragePath(_profile_storage_path)
-                self.cookies = {}
-                cookie_store = self.profile.cookieStore()
-                cookie_store.cookieAdded.connect(self.on_cookie_added)
-                cookie_store.cookieRemoved.connect(self.on_cookie_removed)
 
-            self.view.setPage(BrowserView.WebPage(self, profile=self.profile))
-        elif not is_webengine and not _settings['private_mode']:
+            user_agent = _state['user_agent']
+            if user_agent:
+                self.profile.setHttpUserAgent(user_agent)
+
+            cookie_store = self.profile.cookieStore()
+            cookie_store.cookieAdded.connect(self.on_cookie_added)
+            cookie_store.cookieRemoved.connect(self.on_cookie_removed)
+
+            self.profile.setUrlRequestInterceptor(self.request_interceptor)
+            self.webview.setPage(BrowserView.WebPage(self, profile=self.profile))
+        elif not is_webengine and not _state['private_mode']:
             logger.warning('qtwebkit does not support private_mode')
 
+        user_agent = _state['user_agent']
+        # if user_agent and is_webengine:
+        #     self.profile.setHttpUserAgent(user_agent)
+
         if is_webengine:
             self.profile.settings().setAttribute(
-                QWebEngineSettings.LocalContentCanAccessFileUrls, settings['ALLOW_FILE_URLS'])
+                QWebEngineSettings.WebAttribute.LocalContentCanAccessFileUrls,
+                settings['ALLOW_FILE_URLS'],
+            )
 
-        self.view.page().loadFinished.connect(self.on_load_finished)
+        self.webview.page().loadFinished.connect(self.on_load_finished)
 
         if settings['ALLOW_DOWNLOADS']:
-            self.view.page().profile().downloadRequested.connect(self.on_download_requested)
+            self.webview.page().profile().downloadRequested.connect(self.on_download_requested)
 
-        self.setCentralWidget(self.view)
+        self.setCentralWidget(self.webview)
 
         self.create_window_trigger.connect(BrowserView.on_create_window)
         self.load_url_trigger.connect(self.on_load_url)
@@ -416,33 +474,37 @@ class BrowserView(QMainWindow):
         self.on_top_trigger.connect(self.on_set_on_top)
 
         if is_webengine and platform.system() != 'OpenBSD':
-            self.channel = QWebChannel(self.view.page())
-            self.view.page().setWebChannel(self.channel)
+            self.channel = QWebChannel(self.webview.page())
+            self.webview.page().setWebChannel(self.channel)
 
         if window.fullscreen:
             self.toggle_fullscreen()
 
         if window.real_url is not None:
-            self.view.setUrl(QtCore.QUrl(window.real_url))
+            self.webview.setUrl(QtCore.QUrl(window.real_url))
         elif window.uid == 'web_inspector':
-            self.view.setUrl(QtCore.QUrl(window.original_url))
+            self.webview.setUrl(QtCore.QUrl(window.original_url))
         elif window.html:
-            self.view.setHtml(window.html, QtCore.QUrl(''))
+            self.webview.setHtml(window.html, QtCore.QUrl(''))
         else:
-            self.view.setHtml(DEFAULT_HTML, QtCore.QUrl(''))
+            self.webview.setHtml(DEFAULT_HTML, QtCore.QUrl(''))
 
         if window.initial_x is not None and window.initial_y is not None:
-            self.move(self.screen.x()+window.initial_x, self.screen.y()+window.initial_y)
+            self.move(self.screen.x() + window.initial_x, self.screen.y() + window.initial_y)
         else:
             offset = -16 if _qt6 else 0
             center = self.screen.center() - self.rect().center()
-            self.move(center.x(), center.y()+offset)
+            self.move(center.x(), center.y() + offset)
 
         if not window.minimized:
             self.activateWindow()
             self.raise_()
 
-        self.shown.set()
+        if _state['icon']:
+            icon = QIcon(_state['icon'])
+            self.setWindowIcon(icon)
+
+        self.pywebview_window.events.before_show.set()
 
     def on_set_title(self, title):
         self.setWindowTitle(title)
@@ -460,11 +522,14 @@ class BrowserView(QMainWindow):
         confirmation_dialog_result['semaphore'].release()
 
     def on_file_dialog(self, dialog_type, directory, allow_multiple, save_filename, file_filter):
-        if dialog_type == FOLDER_DIALOG:
+        if dialog_type == FileDialog.FOLDER:
             self._file_name = QFileDialog.getExistingDirectory(
-                self, self.localization['linux.openFolder'], directory, options=QFileDialog.ShowDirsOnly
+                self,
+                self.localization['linux.openFolder'],
+                directory,
+                options=QFileDialog.ShowDirsOnly,
             )
-        elif dialog_type == OPEN_DIALOG:
+        elif dialog_type == FileDialog.OPEN:
             if allow_multiple:
                 self._file_name = QFileDialog.getOpenFileNames(
                     self, self.localization['linux.openFiles'], directory, file_filter
@@ -473,7 +538,7 @@ class BrowserView(QMainWindow):
                 self._file_name = QFileDialog.getOpenFileName(
                     self, self.localization['linux.openFile'], directory, file_filter
                 )
-        elif dialog_type == SAVE_DIALOG:
+        elif dialog_type == FileDialog.SAVE:
             if directory:
                 save_filename = os.path.join(str(directory), str(save_filename))
 
@@ -497,15 +562,15 @@ class BrowserView(QMainWindow):
             del self.cookies[raw]
 
     def on_current_url(self):
-        url = BrowserView._convert_string(self.view.url().toString())
+        url = BrowserView._convert_string(self.webview.url().toString())
         self._current_url = None if url == '' or url.startswith('data:text/html') else url
         self._current_url_semaphore.release()
 
     def on_load_url(self, url):
-        self.view.setUrl(QtCore.QUrl(url))
+        self.webview.setUrl(QtCore.QUrl(url))
 
     def on_load_html(self, content, base_uri):
-        self.view.setHtml(content, QtCore.QUrl(base_uri))
+        self.webview.setHtml(content, QtCore.QUrl(base_uri))
 
     def on_set_on_top(self, top):
         flags = self.windowFlags()
@@ -516,6 +581,9 @@ class BrowserView(QMainWindow):
 
         self.show()
 
+    def showEvent(self, event):
+        self.pywebview_window.events.shown.set()
+
     def closeEvent(self, event):
         should_cancel = self.pywebview_window.events.closing.set()
 
@@ -539,7 +607,6 @@ class BrowserView(QMainWindow):
         event.accept()
 
         del BrowserView.instances[self.uid]
-        self.view.page().deleteLater()
         self.close()
 
         if self.pywebview_window in windows:
@@ -547,6 +614,9 @@ class BrowserView(QMainWindow):
 
         self.pywebview_window.events.closed.set()
 
+        if self.webview.page():
+            self.webview.page().deleteLater()
+
         if len(BrowserView.instances) == 0:
             self.hide()
             _app.exit()
@@ -626,29 +696,32 @@ class BrowserView(QMainWindow):
         self.activateWindow()
 
     def on_evaluate_js(self, script, uuid):
-        def return_result(result):
-            result = BrowserView._convert_string(result)
+        def return_result(result_):
+            result = BrowserView._convert_string(result_)
             uuid_ = BrowserView._convert_string(uuid)
 
             js_result = self._js_results[uuid_]
-            js_result['result'] = (
-                None
-                if result is None or result == 'null'
-                else result
-                if result == ''
-                else json.loads(result)
-            )
+
+            if js_result['parse_json'] and result:
+                try:
+                    js_result['result'] = json.loads(result)
+                except Exception:
+                    logger.exception('Failed to parse JSON: %s', result)
+                    js_result['result'] = result
+            else:
+                js_result['result'] = result
+
             js_result['semaphore'].release()
 
         try:  # < Qt5.6
             if _qt6:
-                self.view.page().runJavaScript(script, 0, return_result)
+                self.webview.page().runJavaScript(script, 0, return_result)
             else:
-                self.view.page().runJavaScript(script, return_result)
+                self.webview.page().runJavaScript(script, return_result)
         except TypeError:
-            self.view.page().runJavaScript(script)  # PySide2 & PySide6
+            self.webview.page().runJavaScript(script)  # PySide2 & PySide6
         except AttributeError:
-            result = self.view.page().mainFrame().evaluateJavaScript(script)
+            result = self.webview.page().mainFrame().evaluateJavaScript(script)
             return_result(result)
         except Exception as e:
             logger.exception(e)
@@ -659,22 +732,14 @@ class BrowserView(QMainWindow):
 
         self._set_js_api()
 
-        if not self.text_select:
-            script = disable_text_select.replace('\n', '')
-
-            try:
-                self.view.page().runJavaScript(script)
-            except:  # QT < 5.6
-                self.view.page().mainFrame().evaluateJavaScript(script)
-
-        if _settings['debug'] and settings['OPEN_DEVTOOLS_IN_DEBUG']:
-            self.view.show_inspector()
+        if _state['debug'] and settings['OPEN_DEVTOOLS_IN_DEBUG']:
+            self.webview.show_inspector()
 
     def on_download_requested(self, download):
         old_path = download.url().path()
         suffix = QtCore.QFileInfo(old_path).suffix()
         path, _ = QFileDialog.getSaveFileName(
-            self, self.localization['global.saveFile'], old_path, "*." + suffix
+            self, self.localization['global.saveFile'], old_path, '*.' + suffix
         )
         if path:
             download.setPath(path)
@@ -686,19 +751,20 @@ class BrowserView(QMainWindow):
     def get_cookies(self):
         return list(self.cookies.values())
 
+    def clear_cookies(self):
+        self.cookies = {}
+        self.profile.cookieStore().deleteAllCookies()
+
     def get_current_url(self):
-        self.loaded.wait()
         self.current_url_trigger.emit()
         self._current_url_semaphore.acquire()
 
         return self._current_url
 
     def load_url(self, url):
-        self.loaded.clear()
         self.load_url_trigger.emit(url)
 
     def load_html(self, content, base_uri):
-        self.loaded.clear()
         self.html_trigger.emit(content, base_uri)
 
     def create_confirmation_dialog(self, title, message):
@@ -725,9 +791,9 @@ class BrowserView(QMainWindow):
         )
         self._file_name_semaphore.acquire()
 
-        if dialog_type == FOLDER_DIALOG:
+        if dialog_type == FileDialog.FOLDER:
             file_names = (self._file_name,)
-        elif dialog_type == SAVE_DIALOG or not allow_multiple:
+        elif dialog_type == FileDialog.SAVE or not allow_multiple:
             file_names = (self._file_name[0],)
         else:
             file_names = tuple(self._file_name[0])
@@ -768,11 +834,14 @@ class BrowserView(QMainWindow):
     def set_on_top(self, top):
         self.on_top_trigger.emit(top)
 
-    def evaluate_js(self, script):
-        self.loaded.wait()
+    def evaluate_js(self, script, parse_json):
         result_semaphore = Semaphore(0)
         unique_id = uuid1().hex
-        self._js_results[unique_id] = {'semaphore': result_semaphore, 'result': ''}
+        self._js_results[unique_id] = {
+            'semaphore': result_semaphore,
+            'result': '',
+            'parse_json': parse_json,
+        }
 
         self.evaluate_js_trigger.emit(script, unique_id)
         result_semaphore.acquire()
@@ -786,38 +855,25 @@ class BrowserView(QMainWindow):
         def _register_window_object():
             frame.addToJavaScriptWindowObject('external', self.js_bridge)
 
-        code = 'qtwebengine' if is_webengine else 'qtwebkit'
-        script = inject_pywebview(self.js_bridge.window, code)
-
         if is_webengine:
             qwebchannel_js = QtCore.QFile('://qtwebchannel/qwebchannel.js')
             if qwebchannel_js.open(QtCore.QFile.ReadOnly):
                 source = bytes(qwebchannel_js.readAll()).decode('utf-8')
-                self.view.page().runJavaScript(source)
+                self.webview.page().runJavaScript(source)
                 self.channel.registerObject('external', self.js_bridge)
                 qwebchannel_js.close()
         else:
-            frame = self.view.page().mainFrame()
+            frame = self.webview.page().mainFrame()
             _register_window_object()
 
-        try:
-            self.view.page().runJavaScript(script)
-        except AttributeError:  # < QT 5.6
-            self.view.page().mainFrame().evaluateJavaScript(script)
-
-        self.loaded.set()
+        inject_pywebview(renderer, self.js_bridge.window)
 
     @staticmethod
     def _convert_string(result):
-        try:
-            if result is None or result.isNull():
-                return None
-
-            result = result.toString()  # QJsonValue conversion
-        except AttributeError:
-            pass
-
-        return str(result)
+        if isinstance(result, QJsonValue):
+            return None if result.isNull() else result.toString()
+        else:
+            return result
 
     @staticmethod
     def _get_debug_port():
@@ -850,9 +906,10 @@ class BrowserView(QMainWindow):
 
 
 def setup_app():
-    # MUST be called before create_window and set_app_menu
     global _app
-    _app = QApplication.instance() or QApplication([])
+    if settings['IGNORE_SSL_ERRORS']:
+        environ_append('QTWEBENGINE_CHROMIUM_FLAGS', '--ignore-certificate-errors')
+    _app = QApplication.instance() or QApplication(sys.argv)
 
 
 def create_window(window):
@@ -860,12 +917,10 @@ def create_window(window):
         browser = BrowserView(window)
         browser.installEventFilter(browser)
 
-        # If the menu we created as part of set_app_menu was not set as the native menu, then
-        #     we need to recreate the menu for every window
-        if BrowserView.global_menubar and not BrowserView.global_menubar.isNativeMenuBar():
+        if window.menu or _app_menu:
+            menu = window.menu or _state['menu']
             window_menubar = browser.menuBar()
-            for menu in BrowserView.global_menubar_top_menus:
-                window_menubar.addMenu(menu)
+            create_menu(menu, window_menubar)
 
         _main_window_created.set()
 
@@ -878,11 +933,29 @@ def create_window(window):
             browser.showMinimized()
         elif not window.hidden:
             browser.show()
+        elif window.hidden:
+            browser.pywebview_window.events.shown.set()
 
     if window.uid == 'master':
-        global _app
+        global _app, _app_menu
+        if _state['menu']:
+            _app_menu = QMenuBar()
+            _app_menu.setNativeMenuBar(False)
+            create_menu(_state['menu'], _app_menu)
+        else:
+            _app_menu = None
+
         _app = QApplication.instance() or QApplication(sys.argv)
 
+        signal.signal(signal.SIGINT, _sigint_handler)
+
+        # Create a timer to periodically allow the Python interpreter to run
+        # This enables the signal handler to be called even when the Qt event loop is running
+        # The timer just calls a no-op function to trigger Python execution
+        timer = QtCore.QTimer()
+        timer.start(500)
+        timer.timeout.connect(lambda: None)
+
         _create()
         _app.exec_()
     else:
@@ -897,6 +970,12 @@ def set_title(title, uid):
         i.set_title(title)
 
 
+def clear_cookies(uid):
+    i = BrowserView.instances.get(uid)
+    if i:
+        i.clear_cookies()
+
+
 def get_cookies(uid):
     i = BrowserView.instances.get(uid)
     if i:
@@ -921,14 +1000,16 @@ def load_html(content, base_uri, uid):
         i.load_html(content, base_uri)
 
 
-def set_app_menu(app_menu_list):
+def create_menu(app_menu_list, menubar):
     """
-    Create a custom menu for the app bar menu (on supported platforms).
-    Otherwise, this menu is used across individual windows.
+    Create the menu bar for the application for the provided QMenuBar object. Menu can be either a global
+    application menu or a window-specific menu.
 
     Args:
         app_menu_list ([webview.menu.Menu])
+        menubar (QMenuBar)
     """
+
     def run_action(func):
         Thread(target=func).start()
 
@@ -949,22 +1030,12 @@ def set_app_menu(app_menu_list):
 
         return m
 
-    # If the application menu has already been created, we don't want to do it again
-    if (
-        len(BrowserView.global_menubar_top_menus) > 0
-        or len(BrowserView.global_menubar_other_objects) > 0
-    ):
-        return
-
-    top_level_menu = QMenuBar()
-    top_level_menu.setNativeMenuBar(True)
-
-    BrowserView.global_menubar = top_level_menu
-
     for app_menu in app_menu_list:
-        BrowserView.global_menubar_top_menus.append(
-            create_submenu(app_menu.title, app_menu.items, top_level_menu)
-        )
+        # Ignore '__app__' menus (macOS-only feature)
+        if app_menu.title == '__app__':
+            continue
+        menu = create_submenu(app_menu.title, app_menu.items, menubar)
+        menubar.addMenu(menu)
 
 
 def get_active_window():
@@ -1053,13 +1124,15 @@ def create_file_dialog(dialog_type, directory, allow_multiple, save_filename, fi
 
     i = BrowserView.instances.get(uid)
     if i:
-        return i.create_file_dialog(dialog_type, directory, allow_multiple, save_filename, file_filter)
+        return i.create_file_dialog(
+            dialog_type, directory, allow_multiple, save_filename, file_filter
+        )
 
 
-def evaluate_js(script, uid):
+def evaluate_js(script, uid, parse_json=True):
     i = BrowserView.instances.get(uid)
     if i:
-        return i.evaluate_js(script)
+        return i.evaluate_js(script, parse_json)
 
 
 def get_position(uid):
@@ -1082,7 +1155,10 @@ def get_size(uid):
 def get_screens():
     global _app
     _app = QApplication.instance() or QApplication(sys.argv)
-    screens = [Screen(s.geometry().width(), s.geometry().height(), s) for s in _app.screens()]
+    screens = [
+        Screen(s.geometry().x(), s.geometry().y(), s.geometry().width(), s.geometry().height(), s)
+        for s in _app.screens()
+    ]
 
     return screens
 
